@@ -11,8 +11,8 @@ index((aggregate_all), 4, aggregate, aggregate).
 index((free_variables), 4, aggregate, aggregate).
 index((ansi_format), 3, ansi_term, ansi_term).
 index((ansi_get_color), 2, ansi_term, ansi_term).
-index((expand_phrase), 2, apply_macros, apply_macros).
-index((expand_phrase), 4, apply_macros, apply_macros).
+index((ansi_hyperlink), 2, ansi_term, ansi_term).
+index((ansi_hyperlink), 3, ansi_term, ansi_term).
 index((include), 3, apply, apply).
 index((exclude), 3, apply, apply).
 index((partition), 4, apply, apply).
@@ -30,6 +30,8 @@ index((scanl), 4, apply, apply).
 index((scanl), 5, apply, apply).
 index((scanl), 6, apply, apply).
 index((scanl), 7, apply, apply).
+index((expand_phrase), 2, apply_macros, apply_macros).
+index((expand_phrase), 4, apply_macros, apply_macros).
 index((archive_open), 3, archive, archive).
 index((archive_open), 4, archive, archive).
 index((archive_create), 3, archive, archive).
@@ -173,13 +175,6 @@ index((open_chars_stream), 2, charsio, charsio).
 index((with_output_to_chars), 2, charsio, charsio).
 index((with_output_to_chars), 3, charsio, charsio).
 index((with_output_to_chars), 4, charsio, charsio).
-index((check_installation), 0, check_installation, check_installation).
-index((check_installation), 1, check_installation, check_installation).
-index((check_config_files), 0, check_installation, check_installation).
-index((update_config_files), 0, check_installation, check_installation).
-index((test_installation), 0, check_installation, check_installation).
-index((test_installation), 1, check_installation, check_installation).
-index((check_old_last), 0, checklast, checklast).
 index((check), 0, check, check).
 index((list_undefined), 0, check, check).
 index((list_undefined), 1, check, check).
@@ -196,6 +191,13 @@ index((list_strings), 0, check, check).
 index((list_strings), 1, check, check).
 index((list_rationals), 0, check, check).
 index((list_rationals), 1, check, check).
+index((check_installation), 0, check_installation, check_installation).
+index((check_installation), 1, check_installation, check_installation).
+index((check_config_files), 0, check_installation, check_installation).
+index((update_config_files), 0, check_installation, check_installation).
+index((test_installation), 0, check_installation, check_installation).
+index((test_installation), 1, check_installation, check_installation).
+index((check_old_last), 0, checklast, checklast).
 index((check_old_select), 0, checkselect, checkselect).
 index((format_to_codes), 3, codesio, codesio).
 index((format_to_codes), 4, codesio, codesio).
@@ -210,6 +212,7 @@ index((with_output_to_codes), 2, codesio, codesio).
 index((with_output_to_codes), 3, codesio, codesio).
 index((with_output_to_codes), 4, codesio, codesio).
 index((coinductive), 1, coinduction, coinduction).
+index((crypt), 2, crypt, crypt).
 index((crypto_n_random_bytes), 2, crypto, crypto).
 index((crypto_data_hash), 3, crypto, crypto).
 index((crypto_file_hash), 3, crypto, crypto).
@@ -239,7 +242,6 @@ index((crypto_name_curve), 2, crypto, crypto).
 index((crypto_curve_order), 2, crypto, crypto).
 index((crypto_curve_generator), 2, crypto, crypto).
 index((crypto_curve_scalar_mult), 4, crypto, crypto).
-index((crypt), 2, crypt, crypt).
 index((csv), 3, csv, csv).
 index((csv), 4, csv, csv).
 index((csv_read_file), 2, csv, csv).
@@ -324,6 +326,8 @@ index((reconsult), 1, edinburgh, edinburgh).
 index((debug), 0, edinburgh, edinburgh).
 index((nodebug), 0, edinburgh, edinburgh).
 index((fileerrors), 2, edinburgh, edinburgh).
+index((edit), 1, prolog_edit, edit).
+index((edit), 0, prolog_edit, edit).
 index((el_wrap), 0, editline, editline).
 index((el_wrap), 4, editline, editline).
 index((el_wrapped), 1, editline, editline).
@@ -340,8 +344,6 @@ index((el_history_events), 2, editline, editline).
 index((el_add_history), 2, editline, editline).
 index((el_write_history), 2, editline, editline).
 index((el_read_history), 2, editline, editline).
-index((edit), 1, prolog_edit, edit).
-index((edit), 0, prolog_edit, edit).
 index((instantiation_error), 1, error, error).
 index((uninstantiation_error), 1, error, error).
 index((type_error), 2, error, error).
@@ -362,6 +364,8 @@ index((fast_write), 1, fastrw, fastrw).
 index((fast_read), 2, fastrw, fastrw).
 index((fast_write), 2, fastrw, fastrw).
 index((fast_write_to_string), 3, fastrw, fastrw).
+index((can_open_file), 2, files, files).
+index((chdir), 1, files, files).
 index((set_time_file), 3, files_ex, filesex).
 index((link_file), 3, files_ex, filesex).
 index((chmod), 2, files_ex, filesex).
@@ -373,8 +377,6 @@ index((make_directory_path), 1, files_ex, filesex).
 index((copy_directory), 2, files_ex, filesex).
 index((delete_directory_and_contents), 1, files_ex, filesex).
 index((delete_directory_contents), 1, files_ex, filesex).
-index((can_open_file), 2, files, files).
-index((chdir), 1, files, files).
 index((reset_gensym), 0, gensym, gensym).
 index((reset_gensym), 1, gensym, gensym).
 index((gensym), 2, gensym, gensym).
@@ -563,6 +565,7 @@ index((argv_usage), 1, prolog_main, main).
 index((cli_parse_debug_options), 2, prolog_main, main).
 index((cli_enable_development_system), 0, prolog_main, main).
 index((make), 0, make, make).
+index((make_reload_file), 1, make, make).
 index((md5_hash), 3, md5, md5).
 index((new_memory_file), 1, memory_file, memfile).
 index((free_memory_file), 1, memory_file, memfile).
@@ -626,7 +629,6 @@ index((odbc_next_result_set), 1, odbc, odbc).
 index((odbc_close_statement), 1, odbc, odbc).
 index((odbc_clone_statement), 2, odbc, odbc).
 index((odbc_free_statement), 1, odbc, odbc).
-index((odbc_cancel_thread), 1, odbc, odbc).
 index((odbc_current_table), 2, odbc, odbc).
 index((odbc_current_table), 3, odbc, odbc).
 index((odbc_table_column), 3, odbc, odbc).
@@ -704,15 +706,38 @@ index((paxos_quorum_ask), 4, paxos, paxos).
 index((paxos_replicate_key), 3, paxos, paxos).
 index((re_match), 2, pcre, pcre).
 index((re_match), 3, pcre, pcre).
+index((re_matchsub), 3, pcre, pcre).
 index((re_matchsub), 4, pcre, pcre).
 index((re_foldl), 6, pcre, pcre).
 index((re_split), 3, pcre, pcre).
 index((re_split), 4, pcre, pcre).
 index((re_replace), 4, pcre, pcre).
+index((re_replace), 5, pcre, pcre).
 index((re_compile), 3, pcre, pcre).
 index((re_flush), 0, pcre, pcre).
 index((re_config), 1, pcre, pcre).
 index((pdt_install_console), 0, pdt_console, pdt_console).
+index((pengine_create), 1, pengines, pengines).
+index((pengine_ask), 3, pengines, pengines).
+index((pengine_next), 2, pengines, pengines).
+index((pengine_stop), 2, pengines, pengines).
+index((pengine_event), 2, pengines, pengines).
+index((pengine_input), 2, pengines, pengines).
+index((pengine_output), 1, pengines, pengines).
+index((pengine_respond), 3, pengines, pengines).
+index((pengine_debug), 2, pengines, pengines).
+index((pengine_self), 1, pengines, pengines).
+index((pengine_pull_response), 2, pengines, pengines).
+index((pengine_destroy), 1, pengines, pengines).
+index((pengine_destroy), 2, pengines, pengines).
+index((pengine_abort), 1, pengines, pengines).
+index((pengine_application), 1, pengines, pengines).
+index((current_pengine_application), 1, pengines, pengines).
+index((pengine_property), 2, pengines, pengines).
+index((pengine_user), 1, pengines, pengines).
+index((pengine_event_loop), 2, pengines, pengines).
+index((pengine_rpc), 2, pengines, pengines).
+index((pengine_rpc), 3, pengines, pengines).
 index((pengine_writeln), 1, pengines_io, pengines_io).
 index((pengine_nl), 0, pengines_io, pengines_io).
 index((pengine_tab), 1, pengines_io, pengines_io).
@@ -753,6 +778,7 @@ index((run_tests), 1, plunit, plunit).
 index((load_test_files), 1, plunit, plunit).
 index((running_tests), 0, plunit, plunit).
 index((current_test), 5, plunit, plunit).
+index((current_test_unit), 2, plunit, plunit).
 index((test_report), 1, plunit, plunit).
 index((porter_stem), 2, porter_stem, porter_stem).
 index((unaccent_atom), 2, porter_stem, porter_stem).
@@ -791,6 +817,7 @@ index((autoload_all), 0, prolog_autoload, prolog_autoload).
 index((autoload_all), 1, prolog_autoload, prolog_autoload).
 index((set_breakpoint), 4, prolog_breakpoints, prolog_breakpoints).
 index((set_breakpoint), 5, prolog_breakpoints, prolog_breakpoints).
+index((set_breakpoint_condition), 2, prolog_breakpoints, prolog_breakpoints).
 index((delete_breakpoint), 1, prolog_breakpoints, prolog_breakpoints).
 index((breakpoint_property), 2, prolog_breakpoints, prolog_breakpoints).
 index((clause_info), 4, prolog_clause, prolog_clause).
@@ -865,12 +892,15 @@ index((file_name_on_path), 2, prolog_source, prolog_source).
 index((file_alias_path), 2, prolog_source, prolog_source).
 index((path_segments_atom), 2, prolog_source, prolog_source).
 index((directory_source_files), 3, prolog_source, prolog_source).
+index((valid_term_position), 2, prolog_source, prolog_source).
 index((get_prolog_backtrace), 2, prolog_stack, prolog_stack).
 index((get_prolog_backtrace), 3, prolog_stack, prolog_stack).
 index((prolog_stack_frame_property), 2, prolog_stack, prolog_stack).
 index((print_prolog_backtrace), 2, prolog_stack, prolog_stack).
 index((print_prolog_backtrace), 3, prolog_stack, prolog_stack).
 index((backtrace), 1, prolog_stack, prolog_stack).
+index((print_last_choicepoint), 0, prolog_stack, prolog_stack).
+index((print_last_choicepoint), 2, prolog_stack, prolog_stack).
 index((open_prolog_stream), 4, prolog_stream, prolog_stream).
 index((trace), 1, prolog_trace, prolog_trace).
 index((trace), 2, prolog_trace, prolog_trace).
@@ -1021,16 +1051,16 @@ index((ord_list_to_rbtree), 2, rbtrees, rbtrees).
 index((is_rbtree), 1, rbtrees, rbtrees).
 index((rb_size), 2, rbtrees, rbtrees).
 index((rb_in), 3, rbtrees, rbtrees).
+index((load_rdf), 2, rdf, rdf).
+index((load_rdf), 3, rdf, rdf).
+index((xml_to_rdf), 3, rdf, rdf).
+index((process_rdf), 3, rdf, rdf).
 index((rdf_diagram_from_file), 1, rdf_diagram, rdf_diagram).
 index((xml_to_plrdf), 3, rdf_parser, rdf_parser).
 index((element_to_plrdf), 3, rdf_parser, rdf_parser).
 index((make_rdf_state), 3, rdf_parser, rdf_parser).
 index((rdf_modify_state), 3, rdf_parser, rdf_parser).
 index((rdf_name_space), 1, rdf_parser, rdf_parser).
-index((load_rdf), 2, rdf, rdf).
-index((load_rdf), 3, rdf, rdf).
-index((xml_to_rdf), 3, rdf, rdf).
-index((process_rdf), 3, rdf, rdf).
 index((rdf_triples), 2, rdf_triple, rdf_triple).
 index((rdf_triples), 3, rdf_triple, rdf_triple).
 index((rdf_reset_ids), 0, rdf_triple, rdf_triple).
@@ -1177,7 +1207,6 @@ index((current_foreign_library), 2, shlib, shlib).
 index((reload_foreign_libraries), 0, shlib, shlib).
 index((use_foreign_library), 1, shlib, shlib).
 index((use_foreign_library), 2, shlib, shlib).
-index((win_add_dll_directory), 1, shlib, shlib).
 index((snowball), 3, snowball, snowball).
 index((snowball_current_algorithm), 1, snowball, snowball).
 index((tcp_socket), 1, socket, socket).
@@ -1271,6 +1300,7 @@ index((delete_stream_from_pool), 1, stream_pool, streampool).
 index((close_stream_pool), 0, stream_pool, streampool).
 index((dispatch_stream_pool), 1, stream_pool, streampool).
 index((stream_pool_main_loop), 0, stream_pool, streampool).
+index((with_output_to), 3, streams, streams).
 index((dedent_lines), 3, strings, strings).
 index((indent_lines), 3, strings, strings).
 index((indent_lines), 4, strings, strings).
@@ -1304,6 +1334,8 @@ index((prefix_string), 3, table, table).
 index((prefix_string), 4, table, table).
 index((sub_string), 3, table, table).
 index((table_version), 2, table, table).
+index((sort_table), 2, table_util, table_util).
+index((verify_table_order), 1, table_util, table_util).
 index((abolish_all_tables), 0, tables, tables).
 index((abolish_module_tables), 1, tables, tables).
 index((abolish_table_pred), 1, tables, tables).
@@ -1322,8 +1354,8 @@ index((get_returns_for_call), 2, tables, tables).
 index((get_residual), 2, tables, tables).
 index((set_pil_on), 0, tables, tables).
 index((set_pil_off), 0, tables, tables).
-index((sort_table), 2, table_util, table_util).
-index((verify_table_order), 1, table_util, table_util).
+index((term_to_json), 3, term_to_json, term_to_json).
+index((term_to_json), 2, term_to_json, term_to_json).
 index((term_hash), 2, terms, terms).
 index((term_hash), 4, terms, terms).
 index((term_size), 2, terms, terms).
