@@ -113,7 +113,7 @@
                        case_preserving_attributes(boolean),
                        system_entities(boolean),
                        max_memory(integer),
-                       space(oneof([sgml,preserve,default,remove])),
+                       space(oneof([sgml,preserve,default,remove,strict])),
                        xmlns(atom),
                        xmlns(atom,atom),
                        pass_to(sgml_parse/2, 2)
@@ -283,17 +283,6 @@ load_dtd(DTD, DtdFile, Options) :-
             close(DtdIn)),
         close(DtdOut)).
 
-split_dtd_options([], [], []).
-split_dtd_options([H|T], [H|TD], S) :-
-    dtd_option(H),
-    !,
-    split_dtd_options(T, TD, S).
-split_dtd_options([H|T], TD, [H|S]) :-
-    split_dtd_options(T, TD, S).
-
-dtd_option(dialect(_)).
-
-
 %!  destroy_dtds
 %
 %   Destroy  DTDs  cached  by  this  thread   as  they  will  become
@@ -314,7 +303,9 @@ register_cleanup :-
     registered_cleanup,
     !.
 register_cleanup :-
-    (   current_prolog_flag(threads, true)
+    (   thread_self(main)
+    ->  at_halt(destroy_dtds)
+    ;   current_prolog_flag(threads, true)
     ->  prolog_listen(this_thread_exit, destroy_dtds)
     ;   true
     ),
